@@ -4,7 +4,7 @@
 /*           http://open-jtalk.sourceforge.net/                      */
 /* ----------------------------------------------------------------- */
 /*                                                                   */
-/*  Copyright (c) 2008-2014  Nagoya Institute of Technology          */
+/*  Copyright (c) 2008-2015  Nagoya Institute of Technology          */
 /*                           Department of Computer Science          */
 /*                                                                   */
 /* All rights reserved.                                              */
@@ -55,9 +55,11 @@ NJD_SET_DIGIT_RULE_H_START;
 #define NJD_SET_DIGIT_SUUSETSUZOKU "³"
 #define NJD_SET_DIGIT_JOSUUSHI ""
 #define NJD_SET_DIGIT_FUKUSHIKANOU "ǽ"
-#define NJD_SET_DIGIT_HAIHUN1 ""
-#define NJD_SET_DIGIT_HAIHUN2 ""
-#define NJD_SET_DIGIT_HAIHUN3 ""
+#define NJD_SET_DIGIT_HAIHUN1 ""     /* horizontal bar */
+#define NJD_SET_DIGIT_HAIHUN2 ""     /* minus sign */
+#define NJD_SET_DIGIT_HAIHUN3 ""     /* hyphen */
+#define NJD_SET_DIGIT_HAIHUN4 ""     /* em dash */
+#define NJD_SET_DIGIT_HAIHUN5 ""     /* fullwidth hyphen-minus */
 #define NJD_SET_DIGIT_KAKKO1 ""
 #define NJD_SET_DIGIT_KAKKO2 ""
 #define NJD_SET_DIGIT_BANGOU "ֹ"
@@ -147,8 +149,8 @@ static const char *njd_set_digit_rule_numeral_list3[] = {
    ",̾,,*,*,*,*,,祦,硼,1/2,C3",
    ",̾,,*,*,*,*,,,,1/2,*",
    "Զ,̾,,*,*,*,*,Զ,,,1/2,*",
-   "ͽ,̾,,*,*,*,*,ͽ,,,1/1,*", /* No character in EUC-JP */
-   ",̾,,*,*,*,*,,祦,祦,1/2,*",
+   "ͽ,̾,,*,*,*,*,ͽ,,,1/1,*", /* none in this charcode */
+   ",̾,,*,*,*,*,,祦,硼,1/2,*",
    ",̾,,*,*,*,*,,,,1/2,*",
    ",̾,,*,*,*,*,,,,1/2,*",
    ",̾,,*,*,*,*,,,,1/2,*",
@@ -168,7 +170,9 @@ static const char *njd_set_digit_rule_numeral_list4[] = {
 };
 
 static const char *njd_set_digit_rule_numeral_list5[] = {
-   "", "ɴ", "", "", "", "", "", "Զ", "ͽ", "", "", "", "", "", "",
+   "", "ɴ", "", "", "", "", "", "Զ",
+   "ͽ", /* none in this charcode */
+   "", "", "", "", "", "",
    "Ϻ", "ε", "ͳ¾", "ԲĻ׵", "̵",
    NULL
 };
@@ -304,7 +308,7 @@ static const char *njd_set_digit_rule_numerative_class1g[] = {
    "", "", "", "", "", "", "", "", "", "", "", "", "ǯ", "",
    "Ԥ", "ڤ", "", "", "", "", "", "", "", "", "", "ɤ", "ɤ", "ɮ", "ɶ",
    "ɼ", "", "ʬ", "ʬ", "", "", "", "", "", "", "", "", "", "", "",
-   "ˡ", "Ω",
+   "ˡ", "Ω", "Ƭ",
    NULL
 };
 
@@ -331,6 +335,7 @@ static const char *njd_set_digit_rule_numerative_class1h[] = {
    "ޤ", "Ȥ", "Ȥ", "Ȥ", "Ȥ", "", "", "", "«", "³", "", "",
    "", "î", "ȿ", "", "", "Ļ", "", "Ϥ", "", "ũ", "Ź", "ž", "", "", "",
    "", "", "", "", "", "ʬ", "", "", "", "γ", "", "", "",
+   "ּ",
    NULL
 };
 
@@ -381,7 +386,7 @@ static const char *njd_set_digit_rule_numerative_class1k[] = {
    "", "", "ѡ", "ѡߥ", "ѥ", "ѥå", "ѥå", "ԡԡ",
    "ԥ", "ڡ", "", "ڥ", "ڥ", "ڥ", "ڥˡ", "ڥ˥", "ڥ", "ݥ",
    "", "", "", "ĥ", "ʿ", "ʿ", "ʿ᡼ȥ", "ʿ᡼ȥ",
-   "ʿ᡼ȥ",
+   "ʿ᡼ȥ", "",
    NULL
 };
 
@@ -435,7 +440,7 @@ static const char *njd_set_digit_rule_conv_table2c[] = {
 };
 
 static const char *njd_set_digit_rule_numerative_class2d[] = {
-/* from paper */
+   /* from paper */
    /* "", "", *//* modified */
    NULL
 };
@@ -600,11 +605,12 @@ static const char *njd_set_digit_rule_conv_table5[] = {
    "", ",̾,ǽ,*,*,*,*,,ĥ,ĥ,0/3,*",
    "ϻ", "ϻ,̾,ǽ,*,*,*,*,ϻ,।,।,0/3,*",
    "", ",̾,ǽ,*,*,*,*,,ʥΥ,ʥΥ,0/3,*",
-   "Ȭ", "Ȭ,̾,ǽ,*,*,*,*,Ȭ,襦,襦,0/3,*",
+   "Ȭ", "Ȭ,̾,ǽ,*,*,*,*,Ȭ,襦,衼,0/3,*",
    "", ",̾,ǽ,*,*,*,*,,Υ,Υ,0/4,*",
    "", ",̾,ǽ,*,*,*,*,,ȥ,ȡ,0/3,*",
    NULL, NULL
 };
+
 static const char *njd_set_digit_rule_conv_table6[] = {
    "", ",̾,ǽ,*,*,*,*,,˥,˥,4/6,*",
    "", ",̾,ǽ,*,*,*,*,,եĥ,եĥ,3/5,*",
@@ -613,7 +619,7 @@ static const char *njd_set_digit_rule_conv_table6[] = {
    "", ",̾,ǽ,*,*,*,*,,ĥ,ĥ,3/5,*",
    "ϻ", "ϻ,̾,ǽ,*,*,*,*,ϻ,।,।,3/5,*",
    "", ",̾,ǽ,*,*,*,*,,ʥΥ,ʥΥ,3/5,*",
-   "Ȭ", "Ȭ,̾,ǽ,*,*,*,*,Ȭ,襦,襦,3/5,*",
+   "Ȭ", "Ȭ,̾,ǽ,*,*,*,*,Ȭ,襦,衼,3/5,*",
    "", ",̾,ǽ,*,*,*,*,,Υ,Υ,4/6,*",
    "", ",̾,ǽ,*,*,*,*,,ȥ,ȡ,3/5,*",
    NULL, NULL
