@@ -4,7 +4,7 @@
 /*           http://open-jtalk.sourceforge.net/                      */
 /* ----------------------------------------------------------------- */
 /*                                                                   */
-/*  Copyright (c) 2008-2014  Nagoya Institute of Technology          */
+/*  Copyright (c) 2008-2015  Nagoya Institute of Technology          */
 /*                           Department of Computer Science          */
 /*                                                                   */
 /* All rights reserved.                                              */
@@ -55,9 +55,11 @@ NJD_SET_DIGIT_RULE_H_START;
 #define NJD_SET_DIGIT_SUUSETSUZOKU "ڑ"
 #define NJD_SET_DIGIT_JOSUUSHI ""
 #define NJD_SET_DIGIT_FUKUSHIKANOU "\"
-#define NJD_SET_DIGIT_HAIHUN1 "\"
-#define NJD_SET_DIGIT_HAIHUN2 "|"
-#define NJD_SET_DIGIT_HAIHUN3 "]"
+#define NJD_SET_DIGIT_HAIHUN1 "\"     /* horizontal bar */
+#define NJD_SET_DIGIT_HAIHUN2 "|"     /* minus sign */
+#define NJD_SET_DIGIT_HAIHUN3 "]"     /* hyphen */
+#define NJD_SET_DIGIT_HAIHUN4 "\"     /* em dash */
+#define NJD_SET_DIGIT_HAIHUN5 "|"     /* fullwidth hyphen-minus */
 #define NJD_SET_DIGIT_KAKKO1 "i"
 #define NJD_SET_DIGIT_KAKKO2 "j"
 #define NJD_SET_DIGIT_BANGOU "ԍ"
@@ -145,20 +147,20 @@ static const char *njd_set_digit_rule_numeral_list3[] = {
    ",,,*,*,*,*,,},},1/2,*",
    ",,,*,*,*,*,,IN,IN,1/2,*",
    ",,,*,*,*,*,,`E,`[,1/2,C3",
-   ",,,*,*,*,*,,PC,PC,1/2,*",
+   ",,,*,*,*,*,,PC,P[,1/2,*",
    ",,,*,*,*,*,,KC,KC,1/2,*",
-   "ї\,,,*,*,*,*,ї\,W,W,1/1,*", /* No character in EUC-JP */
-   ",,,*,*,*,*,,WE,WE,1/2,*",
+   "ї\,,,*,*,*,*,ї\,W,W,1/1,*", /* none in this charcode */
+   ",,,*,*,*,*,,WE,W[,1/2,*",
    "a,,,*,*,*,*,a,RE,RE,1/2,*",
    ",,,*,*,*,*,,J,J,1/2,*",
-   ",,,*,*,*,*,,ZC,ZC,1/2,*",
+   ",,,*,*,*,*,,ZC,Z[,1/2,*",
    ",,,*,*,*,*,,TC,TC,1/2,*",
    ",,,*,*,*,*,,SN,SN,1/2,*",
    "P͍,,,*,*,*,*,P͍,SEKV,SEKV,1/4,*",
-   "m_,,,*,*,*,*,m_,A\EM,A\EM,2/4,*",
+   "m_,,,*,*,*,*,m_,A\EM,A\[M,2/4,*",
    "ߗR,,,*,*,*,*,ߗR,i^,i^,1/3,*",
    "svc,,,*,*,*,*,svc,tJVM,tJVM,2/4,*",
-   "ʑ吔,,,*,*,*,*,ʑ吔,E^CXE,[^CXE,6/7,*",
+   "ʑ吔,,,*,*,*,*,ʑ吔,E^CXE,[^CX[,6/7,*",
    NULL
 };
 
@@ -168,7 +170,9 @@ static const char *njd_set_digit_rule_numeral_list4[] = {
 };
 
 static const char *njd_set_digit_rule_numeral_list5[] = {
-   "\", "S", "", "", "", "", "", "", "ї\", "", "a", "", "", "", "",
+   "\", "S", "", "", "", "", "", "",
+   "ї\", /* none in this charcode */
+   "", "a", "", "", "", "",
    "P͍", "m_", "ߗR", "svc", "ʑ吔",
    NULL
 };
@@ -304,7 +308,7 @@ static const char *njd_set_digit_rule_numerative_class1g[] = {
    "", "P^", "Z", "`", "s", "", "g", "", "", "", "", "", "N", "",
    "҂", "؂", "g", "h", "s", "t", "", "", "", "", "", "C", "C", "M", "U",
    "[", "i", "", "", "", "", "", "", "", "", "", "", "", "", "",
-   "@", "{",
+   "@", "{", "g",
    NULL
 };
 
@@ -331,6 +335,7 @@ static const char *njd_set_digit_rule_numerative_class1h[] = {
    "܂", "Ƃ", "Ƃ", "Ƃ", "Ƃ", "", "", "", "", "", "", "",
    "", "M", "", "", "", "", "", "͂", "", "H", "X", "]", "_", "l", "",
    "", "", "", "", "n", "", "", "", "", "", "", "Δn", "I",
+   "Ԏ",
    NULL
 };
 
@@ -381,7 +386,7 @@ static const char *njd_set_digit_rule_numerative_class1k[] = {
    "", "", "p[Zg", "p[~", "pXJ", "pbN", "pbg", "s[s[G",
    "sR", "y[W", "", "yA", "yZ^", "y\", "yj[", "yjq", "yX", "|Cg",
    "U", "j", "", "", "", "L", "L[g", "Z`[g",
-   "[g",
+   "[g", "i",
    NULL
 };
 
@@ -435,7 +440,7 @@ static const char *njd_set_digit_rule_conv_table2c[] = {
 };
 
 static const char *njd_set_digit_rule_numerative_class2d[] = {
-/* from paper */
+   /* from paper */
    /* "H", "c", *//* modified */
    NULL
 };
@@ -600,11 +605,12 @@ static const char *njd_set_digit_rule_conv_table5[] = {
    "", "ܓ,,\,*,*,*,*,ܓ,CcJ,CcJ,0/3,*",
    "Z", "Z,,\,*,*,*,*,Z,CJ,CJ,0/3,*",
    "", ",,\,*,*,*,*,,imJ,imJ,0/3,*",
-   "", ",,\,*,*,*,*,,EJ,EJ,0/3,*",
+   "", ",,\,*,*,*,*,,EJ,[J,0/3,*",
    "", ",,\,*,*,*,*,,RRmJ,RRmJ,0/4,*",
    "\", "\,,\,*,*,*,*,\,gEJ,g[J,0/3,*",
    NULL, NULL
 };
+
 static const char *njd_set_digit_rule_conv_table6[] = {
    "", ",,\,*,*,*,*,,C`j`J,C`j`J,4/6,*",
    "", ",,\,*,*,*,*,,tcJJ,tcJJ,3/5,*",
@@ -613,7 +619,7 @@ static const char *njd_set_digit_rule_conv_table6[] = {
    "", "ܓ,,\,*,*,*,*,ܓ,CcJJ,CcJJ,3/5,*",
    "Z", "Z,,\,*,*,*,*,Z,CJJ,CJJ,3/5,*",
    "", ",,\,*,*,*,*,,imJJ,imJJ,3/5,*",
-   "", ",,\,*,*,*,*,,EJJ,EJJ,3/5,*",
+   "", ",,\,*,*,*,*,,EJJ,[JJ,3/5,*",
    "", ",,\,*,*,*,*,,RRmJJ,RRmJJ,4/6,*",
    "\", "\,,\,*,*,*,*,\,gEJJ,g[JJ,3/5,*",
    NULL, NULL
